@@ -1,8 +1,10 @@
 local dat = {}
 local info, ver
-
 local datread = require("data/load_dat")
-datread, ver = datread.open("command.dat", nil)
+do
+	local convert = require("data/button_char")
+	datread, ver = datread.open("command.dat", "# Command List%-Shorthand", convert)
+end
 
 function dat.check(set, softlist)
 	if softlist or not datread then
@@ -13,8 +15,7 @@ function dat.check(set, softlist)
 	if not status or not info then
 		return nil
 	end
-	local convert = require("data/button_char")
-	info = "#jf\n" .. convert(info)
+	info = "#jf\n" .. info
 	return "Command"
 end
 
